# -*- coding: utf-8 -*-
# Tracer un graphe de fonction par approximation
# (programme de seconde)
#    F. Goichot, décembre 2017
#       version utilisant le module "tortue" 
#       traduit et simplifié du module Python standard "turtle"

from math import * # si on veut utiliser cos, pi, sqrt, etc pour la fonction
from tortue import *

def g(x):
    '''la fonction qu'on veut représenter'''
    return(2*x*x-3*x+1)

# On représentera f sur [a,b]. ATTENTION,
# on suppose a < b et b > 0 

# On construit le tableau de valeurs et on détermine le min et le max de
# f sur [a,b], pour pouvoir ensuite adapter le repère 

def table_valeurs(f,a,b,n):
    '''retourne deux tableaux (listes) : lx, de  n points régulièrement 
    répartis entre a et b, et lf, des valeurs de la fonction f en ces points ;
    relève en passant les valeurs mini et maxi rencontrées pour f(x)'''
    lx,lf = [],[]
    mini, maxi = f(a), f(a)
    for i in range(n) :
        xi = a + i * (b-a)/(n-1) ; yi = f(xi)
        lx.append(xi) ; lf.append(yi)
        if yi < mini :
            min = yi
        elif yi > maxi :
            maxi = yi
    return(lx,lf,mini,maxi)
 
# Dessin du graphe (approximatif, en reliant un nombre fini de points)

def dessin(f,a,b,n,c='red'):
    '''dessine l'approximation du graphe de f   
    obtenue en reliant les points (xi,f(xi)) avec la couleur c, rouge par défaut'''
    lx,lf,mini,maxi = table_valeurs(f,a,b,n)
    maz()  # efface et remet à zéro
    vitesse(1)  #  vitesse minimale
    titre('Graphe de fonction')
    taille_fenetre(0.5,0.5) # la fenêtre tortue occupera 1/4 de l'écran
    position_fenetre(-5,0)  # dans le coin supérieur droit
    # on veut un repère avec des marges autour du dessin, d'où le petit calcul :
    largtot = b - min(0,a) ; hauttot = max(maxi,0) - min(mini,0)
    xmin = min(0,a) - largtot * 0.1
    xmax = b + largtot * 0.1
    ymin = min(mini,0) - hauttot * 0.1
    ymax = max(maxi,0) + hauttot * 0.1
    # on adapte le repère
    change_repere(xmin,ymin,xmax,ymax)
    montre()
    # dessin des axes
    couleur('n')
    leve() ; va_en(xmin,0) ; baisse() ; va_en(xmax,0) ; ecrire('x','d',16)
    leve() ; va_en(0,ymin) ; baisse() ; va_en(0,ymax) ; ecrire('y','d',16)
    # dessin du graphe
    couleur('b')
    leve() ; va_en(lx[0],lf[0]) ; baisse() 
    ecrire('('+str(lx[0])+' ,'+str(lf[0])+')', taille=12) # (a,f(a))
    for i in range(1,n):
        va_en(lx[i],lf[i])
    ecrire('('+str(lx[n-1])+' ,'+str(lf[n-1])+')','d',12) # (b,f(b))
    cache()
    
dessin(g,-2,3,10)

 

